@@ -3,6 +3,7 @@
  * GData Client
  * Copyright (C) Thibault Saunier 2009 <saunierthibault@gmail.com>
  * Copyright (C) Philip Withnall 2010 <philip@tecnocode.co.uk>
+ * Copyright (C) Red Hat, Inc. 2016
  *
  * GData Client is free software; you can redistribute it and/or
  * modify it under the terms of the GNU Lesser General Public
@@ -84,7 +85,7 @@
  * </example>
  *
  * Since: 0.4.0
- **/
+ */
 
 #include <config.h>
 #include <glib.h>
@@ -93,16 +94,21 @@
 #include <string.h>
 
 #include "gdata-documents-spreadsheet.h"
+#include "gdata-documents-utils.h"
 #include "gdata-parser.h"
 #include "gdata-private.h"
 
+static void gdata_documents_spreadsheet_constructed (GObject *object);
+
 G_DEFINE_TYPE (GDataDocumentsSpreadsheet, gdata_documents_spreadsheet, GDATA_TYPE_DOCUMENTS_DOCUMENT)
 
 static void
 gdata_documents_spreadsheet_class_init (GDataDocumentsSpreadsheetClass *klass)
 {
+	GObjectClass *gobject_class = G_OBJECT_CLASS (klass);
 	GDataEntryClass *entry_class = GDATA_ENTRY_CLASS (klass);
 
+	gobject_class->constructed = gdata_documents_spreadsheet_constructed;
 	entry_class->kind_term = "http://schemas.google.com/docs/2007#spreadsheet";
 }
 
@@ -112,6 +118,15 @@ gdata_documents_spreadsheet_init (GDataDocumentsSpreadsheet *self)
 	/* Why am I writing it? */
 }
 
+static void
+gdata_documents_spreadsheet_constructed (GObject *object)
+{
+	G_OBJECT_CLASS (gdata_documents_spreadsheet_parent_class)->constructed (object);
+
+	if (!_gdata_parsable_is_constructed_from_xml (GDATA_PARSABLE (object)))
+		gdata_documents_utils_add_content_type (GDATA_DOCUMENTS_ENTRY (object), "application/vnd.google-apps.spreadsheet");
+}
+
 /**
  * gdata_documents_spreadsheet_new:
  * @id: (allow-none): the entry's ID (not the document ID of the spreadsheet), or %NULL
@@ -121,7 +136,7 @@ gdata_documents_spreadsheet_init (GDataDocumentsSpreadsheet *self)
  * Return value: (transfer full): a new #GDataDocumentsSpreadsheet, or %NULL; unref with g_object_unref()
  *
  * Since: 0.4.0
- **/
+ */
 GDataDocumentsSpreadsheet *
 gdata_documents_spreadsheet_new (const gchar *id)
 {
@@ -146,7 +161,7 @@ gdata_documents_spreadsheet_new (const gchar *id)
  * Return value: the download URI; free with g_free()
  *
  * Since: 0.5.0
- **/
+ */
 gchar *
 gdata_documents_spreadsheet_get_download_uri (GDataDocumentsSpreadsheet *self, const gchar *export_format, gint gid)
 {
